# fuggle
Fugue for Kaggle users


## Release History

### 0.0.6

* Fix rendering issue

### 0.0.5

* Fine tune of the experience

### 0.0.4

* Add plot extensions

### <= 0.0.3

* Setup basic functions
